# -*- coding: utf-8 -*-

# htmlwriter.py
# 
# This file is part of Oqapy serie 3
#
# Author: Vincent Vande Vyvre <vincent.vandevyvre@oqapy.eu>
# Home: http://www.oqapy.eu
# Copyright: 2009-2018 Vincent Vande Vyvre
# Licence: GPL3
#
# Creator for OpenStreetMap html

import os
import urllib2
import logging
logger = logging.getLogger(__name__)

class HtmlWriter(object):
    def __init__(self, fld):
        self.fld = fld
        self.osmap = True
        self.gmap = True
        self.osmfile = os.path.join(fld, 'osm.html')
        self.osmscript = os.path.join(fld, 'OpenLayers.js')
        #self.get_javascript()

    def get_url(self):
        return self.osmfile

    def get_javascript(self):
        # OpenStreetMap
        url = "http://www.openlayers.org/api/OpenLayers.js"
        logger.info('Get OpenMap javascript')
        try:
            content = urllib2.urlopen(url).read()
            logger.info('OSMap loaded')
        except Exception as why:
            logger.info('OSMap reading page error: {0}'.format(why))

        else:
            with open(self.osmscript, 'w') as objf:
                try:
                    objf.write(content)
                    self.osmap = True
                except Exception as why:
                    logger.info('OSMap writing page error: {0}'.format(why))

    def write(self, args):
        self.build_osm_script(args[0], args[1], args[2])
        self.build_gm_script(args[0], args[1], args[2])

    def build_osm_script(self, height):
        self.osmap = False
        #OpenStreetMap
        #coord = ", ".join([lon, lat, elev])
        text = """<!DOCTYPE html>
<!-- https://openlayers.org/en/latest/apidoc -->
<!-- https://developer.mozilla.org/fr/docs/Web/JavaScript/Reference -->
<html>
  <head>
    <title>Accessible Map</title>
    <link rel="stylesheet" href="ol.css" type="text/css">
    <script src="https://openlayers.org/en/v4.1.0/build/ol.js"></script>
  </head>
  <body>
    <div id="map" class="map" tabindex="0" style="width: 100%; height: {0};"></div>
    <script>
      var map = new ol.Map({
        target: 'map',
        layers: [
          new ol.layer.Tile({
            preload: 8,
            source: new ol.source.OSM()
          })
        ],
        // Improve user experience by loading tiles while animating. Will make
        // animations stutter on mobile or slow devices.
        loadTilesWhileAnimating: true,
        view: new ol.View({
          center: [0, 0],
          zoom: 2
        })
      });

      document.getElementById('zoom-out').onclick = function() {
        var view = map.getView();
        var zoom = view.getZoom();
        view.setZoom(zoom - 1);
      };

      document.getElementById('zoom-in').onclick = function() {
        var view = map.getView();
        var zoom = view.getZoom();
        view.setZoom(zoom + 1);
      };

      function flyTo(lat, lon) {
        var x = parseFloat(lon);
        var y = parseFloat(lat);
        var location = ol.proj.fromLonLat([x, y]);
        var duration = 2000;
        var view = map.getView();
        var zoom = view.getZoom();
        var parts = 2;
        var called = false;
        function callback(complete) {
          --parts;
          if (called) {
            return;
          }
          if (parts === 0 || !complete) {
            called = true;
          }
        }
        view.animate({
          center: location,
          duration: duration
        }, callback);
        view.animate({
          zoom: zoom / 2,
          duration: duration / 2
        }, {
          zoom: zoom,
          duration: duration / 2
        }, callback);
      };

      function updateLatLonFields() {
        var view = map.getView();
        var center = view.getCenter();
        var lonLat = ol.proj.toLonLat(center);
        var zoom = view.getZoom();
        var values = [lonLat[0], lonLat[1], zoom];
        return (values);
      };

      function centerOnLatLon(lat, lon, zoom) {
        var x = parseFloat(lon);
        var y = parseFloat(lat);
        var centerAt = [x, y];
        var newPos = ol.proj.fromLonLat(centerAt);
        var view = map.getView();
        view.setCenter(newPos);
        view.setZoom(zoom);
      };
    </script>
  </body>
</html>""".format(height)

        try:
            with open(self.osmfile, "w") as objf:
                objf.write(text)
        except Exception as why:
            logger.warning("Unable to create script osm {0} \n   Reason: {1}"
                            .format(self.osmfile, why))

        else:
            self.osmap = True

