# -*- coding: utf-8 -*-

# alignmenttoolbox.py
# this file is part of Oqapy serie 3
#
# Author: Vincent Vande Vyvre <vincent.vandevyvre@oqapy.eu>
# Home: http://www.oqapy.eu
# Copyright: 2010-2019 Vincent Vande Vyvre
# Licence: GPL3
#
# alignment - distribution tool box


import logging
lgg = logging.getLogger(__name__)

from PyQt5.QtCore import Qt, QSize
from PyQt5.QtGui import QIcon, QPixmap
from PyQt5.QtWidgets import (QWidget, QGridLayout, QVBoxLayout, QHBoxLayout,
                             QLabel, QSpacerItem, QToolButton, QFrame,
                             QSizePolicy)

import stylesheets as styles


class AlignmentToolBox:
    def __init__(self, ui):
        self.ui = ui
        self.widget = ToolBox(self)

    def on_button_clicked(self, button):
        lgg.info("Call action %s" % button)
        if button < 11:
            self.ui.scene.align_selection(button)

        else:
            self.ui.scene.distribute_selection(button)

    def active_widget(self, active):
        self.widget.setEnabled(active)     


class ToolBox(QWidget):
    def __init__(self, driver):
        super().__init__(None)
        self.driver = driver
        self.gridLayout_3 = QGridLayout(self)
        self.gridLayout_3.setContentsMargins(20, 0, 10, 0)
        self.verticalLayout = QVBoxLayout()
        self.alignment_lbl = QLabel(self)
        self.alignment_lbl.setText(_("Alignment"))
        self.verticalLayout.addWidget(self.alignment_lbl)
        self.horizontalLayout = QHBoxLayout()
        sp = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
        self.horizontalLayout.addItem(sp)
        self.gridLayout = QGridLayout()
        self.align_01_btn = Button(1, "medias/align_01.png",
                            _("Align right sides on the anchor\'s left side"),
                            self)
        self.gridLayout.addWidget(self.align_01_btn, 0, 0, 1, 1)
        self.align_02_btn = Button(2, "medias/align_02.png",
                                _("Align left sides"), self)
        self.gridLayout.addWidget(self.align_02_btn, 0, 1, 1, 1)
        self.align_03_btn = Button(3, "medias/align_03.png", 
                                _("Align vertical symetry"), self)
        self.gridLayout.addWidget(self.align_03_btn, 0, 2, 1, 1)
        self.align_04_btn = Button(4, "medias/align_04.png", 
                                _("Align right sides"), self)
        self.gridLayout.addWidget(self.align_04_btn, 0, 3, 1, 1)
        self.align_05_btn = Button(5, "medias/align_05.png",
                            _("Align left sides on the anchor\'s right side"), 
                            self)
        self.gridLayout.addWidget(self.align_05_btn, 0, 4, 1, 1)
        self.align_06_btn = Button(6, "medias/align_06.png",
                            _("Align bottom sides on the anchor\'s top side"),
                            self)
        self.gridLayout.addWidget(self.align_06_btn, 1, 0, 1, 1)
        self.align_07_btn = Button(7, "medias/align_07.png",
                                _("Align top sides"), self)
        self.gridLayout.addWidget(self.align_07_btn, 1, 1, 1, 1)
        self.align_08_btn = Button(8, "medias/align_08.png",
                                _("Align horizontal symetry"), self)
        self.gridLayout.addWidget(self.align_08_btn, 1, 2, 1, 1)
        self.align_09_btn = Button(9, "medias/align_09.png",
                                _("Align bottom sides"), self)
        self.gridLayout.addWidget(self.align_09_btn, 1, 3, 1, 1)
        self.align_10_btn = Button(10, "medias/align_10.png",
                            _("Align top sides on the anchor\'s bottom side"),
                            self)
        self.gridLayout.addWidget(self.align_10_btn, 1, 4, 1, 1)
        self.horizontalLayout.addLayout(self.gridLayout)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.line = QFrame(self)
        self.line.setFrameShape(QFrame.HLine)
        self.line.setFrameShadow(QFrame.Sunken)
        self.verticalLayout.addWidget(self.line)
        self.distribution_lbl = QLabel(self)
        self.distribution_lbl.setText(_("Distribution"))
        self.verticalLayout.addWidget(self.distribution_lbl)
        self.horizontalLayout_2 = QHBoxLayout()
        sp1 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(sp1)
        sp2 = QSpacerItem(36, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(sp2)
        self.gridLayout_2 = QGridLayout()
        self.dist_01_btn = Button(11, "medias/dist_01.png",
                                _("Same gap between left sides"), self)
        self.gridLayout_2.addWidget(self.dist_01_btn, 0, 0, 1, 1)
        self.dist_02_btn = Button(12, "medias/dist_02.png",
                                _("Same gap between center"), self)
        self.gridLayout_2.addWidget(self.dist_02_btn, 0, 1, 1, 1)
        self.dist_03_btn = Button(13, "medias/dist_03.png",
                                _("Same gap between right sides"), self)
        self.gridLayout_2.addWidget(self.dist_03_btn, 0, 2, 1, 1)
        self.dist_04_btn = Button(14, "medias/dist_04.png",
                                _("Same gap between items"), self)
        self.gridLayout_2.addWidget(self.dist_04_btn, 0, 3, 1, 1)
        self.dist_05_btn = Button(15, "medias/dist_05.png",
                                _("Same gap between bottom sides"), self)
        self.gridLayout_2.addWidget(self.dist_05_btn, 1, 0, 1, 1)
        self.dist_06_btn = Button(16, "medias/dist_06.png",
                                _("Same gap between center"), self)
        self.gridLayout_2.addWidget(self.dist_06_btn, 1, 1, 1, 1)
        self.dist_07_btn = Button(17, "medias/dist_07.png",
                                _("Same gap between up sides"), self)
        self.gridLayout_2.addWidget(self.dist_07_btn, 1, 2, 1, 1)
        self.dist_08_btn = Button(18, "medias/dist_08.png",
                                _("Same gap between items"), self)
        self.gridLayout_2.addWidget(self.dist_08_btn, 1, 3, 1, 1)
        self.horizontalLayout_2.addLayout(self.gridLayout_2)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.gridLayout_3.addLayout(self.verticalLayout, 0, 0, 1, 1)


class Button(QToolButton):
    def __init__(self, idx, path, tip, parent=None):
        super().__init__(parent)
        self.index = idx
        self.driver = parent.driver
        self.setMinimumSize(QSize(36, 36))
        icon = QIcon()
        icon.addPixmap(QPixmap(path), QIcon.Normal, QIcon.Off)
        self.setIcon(icon)
        self.setIconSize(QSize(32, 32))
        self.setAutoRaise(True)
        self.setToolTip(tip)

    def mousePressEvent(self, event):
        self.driver.on_button_clicked(self.index)
        QToolButton.mousePressEvent(self, event)

